@@ -45,6 +45,8 @@ sun = "Sunday"
 gprsdataresetter = "Reset GPRS data counter"
 offlineswitcher = "Enable flight mode"
 onlineswitcher = "Disable flight mode"
+silentprofile = "Set 'silent' profile"
+generalprofile = "Set 'general' profile"
 
 class DataCounterResetter(QtGui.QWidget):
     def __init__(self, parent=None):
@@ -158,6 +160,8 @@ class DataCounterResetter(QtGui.QWidget):
         self.eventBuiltin.addItem(gprsdataresetter)
         self.eventBuiltin.addItem(offlineswitcher)
         self.eventBuiltin.addItem(onlineswitcher)
+        self.eventBuiltin.addItem(silentprofile)
+        self.eventBuiltin.addItem(generalprofile)
         self.eventDbusInterface.hide()
         self.eventDbusService.hide()
         self.eventDbusPath.hide()
@@ -519,6 +523,10 @@ class DataCounterResetter(QtGui.QWidget):
                 action.command = str("/opt/alarmed/offlineswitcher.py")
             elif eventInfo["content"] == onlineswitcher:
                 action.command = str("/opt/alarmed/onlineswitcher.py")
+            elif eventInfo["content"] == silentprofile:
+                action.command = str("/bin/ash -c '/opt/alarmed/profileswitcher.py silent'")
+            elif eventInfo["content"] == generalprofile:
+                action.command = str("/bin/ash -c '/opt/alarmed/profileswitcher.py general'")
             
         if eventInfo["interval"] != only_once:
             recurrence = event.add_recurrences(1)[0]
